DevRevMonitoredApp class

Inheritance

Constructors

DevRevMonitoredApp({Key? key, GlobalKey<NavigatorState>? navigatorKey, GlobalKey<ScaffoldMessengerState>? scaffoldMessengerKey, Widget? home, Map<String, WidgetBuilder> routes = const <String, WidgetBuilder>{}, String? initialRoute, RouteFactory? onGenerateRoute, InitialRouteListFactory? onGenerateInitialRoutes, RouteFactory? onUnknownRoute, List<NavigatorObserver> navigatorObservers = const [], Widget builder(BuildContext, Widget?)?, String? title = '', GenerateAppTitle? onGenerateTitle, Color? color, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, ThemeMode? themeMode = ThemeMode.system, Duration themeAnimationDuration = kThemeAnimationDuration, Curve themeAnimationCurve = Curves.linear, Locale? locale, Iterable<LocalizationsDelegate>? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], bool debugShowMaterialGrid = false, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, bool debugShowCheckedModeBanner = true, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, String? restorationScopeId, bool useInheritedMediaQuery = false})
DevRevMonitoredApp.router({Key? key, GlobalKey<ScaffoldMessengerState>? scaffoldMessengerKey, RouterConfig<Object>? routerConfig, RouteInformationProvider? routeInformationProvider, RouteInformationParser<Object>? routeInformationParser, RouterDelegate<Object>? routerDelegate, BackButtonDispatcher? backButtonDispatcher, Widget builder(BuildContext, Widget?)?, String? title, GenerateAppTitle? onGenerateTitle, Color? color, ThemeData? theme, ThemeData? darkTheme, ThemeData? highContrastTheme, ThemeData? highContrastDarkTheme, ThemeMode? themeMode = ThemeMode.system, Duration themeAnimationDuration = kThemeAnimationDuration, Curve themeAnimationCurve = Curves.linear, Locale? locale, Iterable<LocalizationsDelegate>? localizationsDelegates, LocaleListResolutionCallback? localeListResolutionCallback, LocaleResolutionCallback? localeResolutionCallback, Iterable<Locale> supportedLocales = const <Locale>[Locale('en', 'US')], bool debugShowMaterialGrid = false, bool showPerformanceOverlay = false, bool checkerboardRasterCacheImages = false, bool checkerboardOffscreenLayers = false, bool showSemanticsDebugger = false, bool debugShowCheckedModeBanner = true, Map<ShortcutActivator, Intent>? shortcuts, Map<Type, Action<Intent>>? actions, String? restorationScopeId, bool useInheritedMediaQuery = false})

Properties

actions → Map<Type, Action<Intent>>?
The default map of intent keys to actions for the application.
finalinherited
backButtonDispatcher → BackButtonDispatcher?
A delegate that decide whether to handle the Android back button intent.
finalinherited
builder → TransitionBuilder?
A builder for inserting widgets above the Navigator or - when the WidgetsApp.router constructor is used - above the Router but below the other widgets created by the WidgetsApp widget, or for replacing the Navigator/Router entirely.
finalinherited
checkerboardOffscreenLayers → bool
Turns on checkerboarding of layers rendered to offscreen bitmaps.
finalinherited
checkerboardRasterCacheImages → bool
Turns on checkerboarding of raster cache images.
finalinherited
color → Color?
The primary color to use for the application in the operating system interface.
finalinherited
darkTheme → ThemeData?
The ThemeData to use when a 'dark mode' is requested by the system.
finalinherited
debugShowCheckedModeBanner → bool
Turns on a little "DEBUG" banner in debug mode to indicate that the app is in debug mode. This is on by default (in debug mode), to turn it off, set the constructor argument to false. In release mode this has no effect.
finalinherited
debugShowMaterialGrid → bool
Turns on a GridPaper overlay that paints a baseline grid Material apps.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
highContrastDarkTheme → ThemeData?
The ThemeData to use when a 'dark mode' and 'high contrast' is requested by the system.
finalinherited
highContrastTheme → ThemeData?
The ThemeData to use when 'high contrast' is requested by the system.
finalinherited
home → Widget?
The widget for the default route of the app (Navigator.defaultRouteName, which is /).
finalinherited
initialRoute → String?
The name of the first route to show, if a Navigator is built.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale → Locale?
The initial locale for this app's Localizations widget is based on this value.
finalinherited
localeListResolutionCallback → LocaleListResolutionCallback?
This callback is responsible for choosing the app's locale when the app is started, and when the user changes the device's locale.
finalinherited
localeResolutionCallback → LocaleResolutionCallback?
The signature of WidgetsApp.localeResolutionCallback.
finalinherited
localizationsDelegates → Iterable<LocalizationsDelegate>?
The delegates for this app's Localizations widget.
finalinherited
A key to use when building the Navigator.
finalinherited
The list of observers for the Navigator created for this app.
finalinherited
onGenerateInitialRoutes → InitialRouteListFactory?
The routes generator callback used for generating initial routes if initialRoute is provided.
finalinherited
onGenerateRoute → RouteFactory?
The route generator callback used when the app is navigated to a named route.
finalinherited
onGenerateTitle → GenerateAppTitle?
If non-null this callback function is called to produce the app's title string, otherwise title is used.
finalinherited
onNavigationNotification → NotificationListenerCallback<NavigationNotification>?
The callback to use when receiving a NavigationNotification.
finalinherited
onUnknownRoute → RouteFactory?
Called when onGenerateRoute fails to generate a route, except for the initialRoute.
finalinherited
restorationScopeId → String?
The identifier to use for state restoration of this app.
finalinherited
routeInformationParser → RouteInformationParser<Object>?
A delegate to parse the route information from the routeInformationProvider into a generic data type to be processed by the routerDelegate at a later stage.
finalinherited
routeInformationProvider → RouteInformationProvider?
A object that provides route information through the RouteInformationProvider.value and notifies its listener when its value changes.
finalinherited
routerConfig → RouterConfig<Object>?
An object to configure the underlying Router.
finalinherited
routerDelegate → RouterDelegate<Object>?
A delegate that configures a widget, typically a Navigator, with parsed result from the routeInformationParser.
finalinherited
routes → Map<String, WidgetBuilder>?
The application's top-level routing table.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaffoldMessengerKey → GlobalKey<ScaffoldMessengerState>?
A key to use when building the ScaffoldMessenger.
finalinherited
scrollBehavior → ScrollBehavior?
The default ScrollBehavior for the application.
finalinherited
shortcuts → Map<ShortcutActivator, Intent>?
The default map of keyboard shortcuts to intents for the application.
finalinherited
showPerformanceOverlay → bool
Turns on a performance overlay.
finalinherited
showSemanticsDebugger → bool
Turns on an overlay that shows the accessibility information reported by the framework.
finalinherited
supportedLocales → Iterable<Locale>
The list of locales that this app has been localized for.
finalinherited
theme → ThemeData?
Default visual properties, like colors fonts and shapes, for this app's material widgets.
finalinherited
themeAnimationCurve → Curve
The curve to apply when animating theme changes.
finalinherited
themeAnimationDuration → Duration
The duration of animated theme changes.
finalinherited
themeAnimationStyle → AnimationStyle?
Used to override the theme animation curve and duration.
finalinherited
themeMode → ThemeMode?
Determines which theme will be used by the application if both theme and darkTheme are provided.
finalinherited
title → String?
A one-line description used by the device to identify the app for the user.
finalinherited
useInheritedMediaQuery → bool
Deprecated. This setting is now ignored.
finalinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MaterialApp>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited